//
//  DataProvider.swift
//  VoiceMemo
//
//  Created by Screencast on 9/4/16.
//  Copyright © 2016 Treehouse Island, Inc. All rights reserved.
//

import Foundation
import CloudKit

protocol DataProviderDelegate: class {
    func processUpdates(_ updates: [DataProviderUpdate<Memo>])
    func providerFailedWithError(_ error: MemoErrorType)
}

enum DataProviderUpdate<T> {
    case insert(T)
}

class DataProvider {
    
    let manager = CloudPersistenceManager()
    var updates = [DataProviderUpdate<Memo>]()
    
    fileprivate weak var delegate: DataProviderDelegate?
    
    init(delegate: DataProviderDelegate?) {
        self.delegate = delegate
    }
    
    func performQuery(type: QueryType) {
        manager.performQuery(type.query) { result in
            self.processResult(result)
        }
    }
    
    func fetch(recordID id: CKRecordID) {
        manager.fetch(id) { result in
            self.processResult(result)
        }
    }
    
    func save(_ memo: Memo) {
        manager.save(memo) { result in
            self.processResult(result)
        }
    }
    
    fileprivate func processResult(_ result: Result<[Memo]>) {
        DispatchQueue.main.async {
            switch result {
            case .success(let memos):
                self.updates = memos.map { DataProviderUpdate.insert($0) }
                self.delegate?.processUpdates(self.updates)
            case .failure(let error):
                self.delegate?.providerFailedWithError(error)
            }
        }
    }
    
    fileprivate func processResult(_ result: Result<Memo>) {
        DispatchQueue.main.async {
            switch result {
            case .success(let memo):
                self.updates = [DataProviderUpdate.insert(memo)]
                self.delegate?.processUpdates(self.updates)
            case .failure(let error):
                self.delegate?.providerFailedWithError(error)
            }
        }
    }
    
}



























